@@ -117,6 +117,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -154,7 +156,7 @@ class RunTask(
         id: builtins.str,
         *,
         task: aws_cdk.aws_ecs.FargateTaskDefinition,
-        capacity_provider_strategy: typing.Optional[typing.Sequence[aws_cdk.aws_ecs.CapacityProviderStrategy]] = None,
+        capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.CapacityProviderStrategy, typing.Dict[str, typing.Any]]]] = None,
         cluster: typing.Optional[aws_cdk.aws_ecs.ICluster] = None,
         fargate_platform_version: typing.Optional[PlatformVersion] = None,
         launch_type: typing.Optional[LaunchType] = None,
@@ -164,7 +166,7 @@ class RunTask(
         schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -182,6 +184,28 @@ class RunTask(
         :param vpc: The VPC for the Amazon ECS task. Default: - create a new VPC or use existing one
         :param vpc_subnets: The subnets to run the task. Default: - { ec2.SubnetType.PRIVATE_WITH_NAT }
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                task: aws_cdk.aws_ecs.FargateTaskDefinition,
+                capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.CapacityProviderStrategy, typing.Dict[str, typing.Any]]]] = None,
+                cluster: typing.Optional[aws_cdk.aws_ecs.ICluster] = None,
+                fargate_platform_version: typing.Optional[PlatformVersion] = None,
+                launch_type: typing.Optional[LaunchType] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                run_at_once: typing.Optional[builtins.bool] = None,
+                run_on_resource_update: typing.Optional[builtins.bool] = None,
+                schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = RunTaskProps(
             task=task,
             capacity_provider_strategy=capacity_provider_strategy,
@@ -199,29 +223,29 @@ class RunTask(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cluster")
     def cluster(self) -> aws_cdk.aws_ecs.ICluster:
         return typing.cast(aws_cdk.aws_ecs.ICluster, jsii.get(self, "cluster"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connections")
     def connections(self) -> aws_cdk.aws_ec2.Connections:
         '''makes RunTask "connectable".'''
         return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
         '''fargate task security group.'''
         return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "securityGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="runOnceResource")
     def run_once_resource(
         self,
@@ -253,7 +277,7 @@ class RunTaskProps:
         self,
         *,
         task: aws_cdk.aws_ecs.FargateTaskDefinition,
-        capacity_provider_strategy: typing.Optional[typing.Sequence[aws_cdk.aws_ecs.CapacityProviderStrategy]] = None,
+        capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.CapacityProviderStrategy, typing.Dict[str, typing.Any]]]] = None,
         cluster: typing.Optional[aws_cdk.aws_ecs.ICluster] = None,
         fargate_platform_version: typing.Optional[PlatformVersion] = None,
         launch_type: typing.Optional[LaunchType] = None,
@@ -263,7 +287,7 @@ class RunTaskProps:
         schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param task: The Amazon ECS Task definition for AWS Fargate.
@@ -281,6 +305,36 @@ class RunTaskProps:
         '''
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            def stub(
+                *,
+                task: aws_cdk.aws_ecs.FargateTaskDefinition,
+                capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ecs.CapacityProviderStrategy, typing.Dict[str, typing.Any]]]] = None,
+                cluster: typing.Optional[aws_cdk.aws_ecs.ICluster] = None,
+                fargate_platform_version: typing.Optional[PlatformVersion] = None,
+                launch_type: typing.Optional[LaunchType] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                run_at_once: typing.Optional[builtins.bool] = None,
+                run_on_resource_update: typing.Optional[builtins.bool] = None,
+                schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument task", value=task, expected_type=type_hints["task"])
+            check_type(argname="argument capacity_provider_strategy", value=capacity_provider_strategy, expected_type=type_hints["capacity_provider_strategy"])
+            check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
+            check_type(argname="argument fargate_platform_version", value=fargate_platform_version, expected_type=type_hints["fargate_platform_version"])
+            check_type(argname="argument launch_type", value=launch_type, expected_type=type_hints["launch_type"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument run_at_once", value=run_at_once, expected_type=type_hints["run_at_once"])
+            check_type(argname="argument run_on_resource_update", value=run_on_resource_update, expected_type=type_hints["run_on_resource_update"])
+            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
         self._values: typing.Dict[str, typing.Any] = {
             "task": task,
         }
